## dbt-tests-adapter 1.19.1 - October 02, 2025

### Features

- Add new test base for UDFs ([#1268](https://github.com/dbt-labs/dbt-adapters/issues/1268))

### Fixes

- Fix duplicates when hard_deletes new_record is used with custom dbt_valid_to_current ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))
- Fix file fixtures for functions to use proper function property names ([#1365](https://github.com/dbt-labs/dbt-adapters/issues/1365))

### Contributors
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))
